import greenfoot.*;

public class Grid extends World
{
    Aktor txtLevel = new Aktor();
    Aktor btnReset = new Aktor();
    int mapNum;
    
    public Grid()
    {
        super(11, 11, 40);
        setPaintOrder(Bug.class, Mushroom.class);
        addGridLines();
        createButtonImage();
        createMap();
    }
    
    private void addGridLines()
    {
        GreenfootImage bg = getBackground();
        bg.setColor(Color.WHITE);
        for (int i=1; i< getWidth(); i++) bg.fillRect(i*getCellSize()-1, 0, 3, getHeight()*getCellSize());
        for (int i=1; i<getHeight(); i++) bg.fillRect(0, i*getCellSize()-1, getWidth()*getCellSize(), 3);
    }
    
    private void createButtonImage()
    {
        GreenfootImage img = new GreenfootImage(120, 32);
        img.fill();
        img.setColor(new Color(224, 224, 192));
        img.fillRect(3, 3, 114, 26);
        GreenfootImage txt = new GreenfootImage("Reset", 28, Color.BLACK, new Color(0, 0, 0, 0));
        img.drawImage(txt, 60-txt.getWidth()/2, 16-txt.getHeight()/2);
        btnReset.setImage(img);
    }
    
    private void updateTextImage()
    {
        String txt = "Level "+(mapNum+1);
        GreenfootImage img = new GreenfootImage(txt, 28, Color.BLACK, new Color(0, 0, 0, 0));
        txtLevel.setImage(img);
    }
    
    private void createMap()
    {
        removeObjects(getObjects(null)); // clear world of object
        String[] map = Maps.MAP[mapNum]; // get map
        // add objects using map
        for (int r=0; r<map.length; r++) for (int c=0; c<map[r].length(); c++)
        {
            int objNum = "WCMBDS".indexOf(map[r].charAt(c));
            switch (objNum)
            {
                case 0: // "W" (wall)
                    addObject(new Wall(), c, r);
                    break;
                case 1: // "C" (clover)
                    addObject(new Clover(), c, r);
                    break;
                case 2: // "M" (mushroom)
                    addObject(new Mushroom(), c, r);
                    break;
                case 3: // "B" (bug/player)
                    addObject(new Bug(), c, r);
                    break;
                case 4: // "D" (dual -- clover and mushroom)
                    addObject(new Clover(), c, r);
                    addObject(new Mushroom(), c, r);
                    break;
                case 5: // "S" (superposition -- bug and clover)
                    addObject(new Bug(), c, r);
                    addObject(new Clover(), c, r);
                    break;
            }
        }
        addObject(btnReset, 5, 10);
        updateTextImage();
        addObject(txtLevel, 5, 9);
    }
    
    public void act()
    {
        if (Greenfoot.mouseClicked(this)) nextMap();
        if (Greenfoot.mouseClicked(btnReset)) createMap();
    }
    
    private void nextMap()
    {
        mapNum = (mapNum+1)%Maps.MAP.length;
        createMap();
    }
}